# -*- coding: utf-8 -*-
from django.core.files.storage import FileSystemStorage

from ai.utils.antivirus import AVException
from .scanner import AVScanner

av_scanner = AVScanner()


class AVFileSystemStorage(FileSystemStorage):
    def save(self, name, content, max_length=None):
        av_result = av_scanner.has_virus(content)
        if av_result[0] is False:
            return super(AVFileSystemStorage, self).save(name, content, max_length)
        raise AVException(av_result[1])



# -*- coding: utf-8 -*-
from django.conf import settings
from django.db import models
from django.utils.timezone import now
from django.utils.translation import ugettext_lazy as _


class CreatedAtInfo(models.Model):
    created_at = models.DateTimeField(_(u"Erstellt am"), default=now, db_index=True)

    def save(self, *args, **kwargs):
        # just a fallback for old data
        if not self.created_at:
            self.created_at = now()
        super(CreatedAtInfo, self).save(*args, **kwargs)

    class Meta:
        abstract = True


class CommonInfo(CreatedAtInfo, models.Model):
    created_by = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name=_(u"Erstellt von"), blank=True, null=True,
                                   related_name="%(app_label)s_%(class)s_created", on_delete=models.SET_NULL)
    lastmodified_at = models.DateTimeField(_(u"Zuletzt geändert am"), default=now, db_index=True)
    lastmodified_by = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name=_(u"Zuletzt geändert von"), blank=True,
                                        null=True, related_name="%(app_label)s_%(class)s_lastmodified",
                                        on_delete=models.SET_NULL)

    def save(self, *args, **kwargs):
        self.lastmodified_at = now()
        super(CommonInfo, self).save(*args, **kwargs)

    class Meta:
        abstract = True



# -*- coding: utf-8 -*-
import re

from django.conf import settings
from django.core.mail.backends.smtp import EmailBackend as SMTPEmailBackend

EMAIL_BACKEND_DOMAIN_WHITELIST = getattr(settings, 'EMAIL_BACKEND_DOMAIN_WHITELIST', [])
REGEX = r'^[\w\-\.]+@(%s)$' % '|'.join(x for x in EMAIL_BACKEND_DOMAIN_WHITELIST).replace('.', '\.')


class WhitelistEmailBackend(SMTPEmailBackend):
    @staticmethod
    def whitify_mail_adresses(mail_adress_list):
        allowed_recipients = []
        for to in mail_adress_list:
            if re.search(REGEX, to):
                allowed_recipients.append(to)
            else:
                # sende nicht erlaubte Mails an den testuser.t-ped.de Catchall
                allowed_recipients.append("%s@testuser.t-ped.de" % to.replace('@', '_'))
        return allowed_recipients

    def send_messages(self, email_messages):
        """
        Checks if email-recipients are in allowed domains and cancels if not.
        Uses regular smtp-sending afterwards.
        """
        for email in email_messages:
            allowed_recipients = self.whitify_mail_adresses(email.to)
            email.to = allowed_recipients
        super(WhitelistEmailBackend, self).send_messages(email_messages)
